Skip to contents

The geometries have been simplified with a tolerance of 750 m to reduce the level of detail.

Usage

lhd

Format

An object of class sf (inherits from tbl_df, tbl, data.frame) with 15 rows and 5 columns.

NSW Ministry of Health, "Map of local health districts", https://www.health.nsw.gov.au/lhd/Pages/lhd-maps.aspx.

The original dataset is published under the Creative Commons Attribution 4.0 International licence, © State of New South Wales NSW Ministry of Health 2023. For current information go to https://www.health.nsw.gov.au.

Examples

library(ggplot2)
ggplot(lhd) + geom_sf(aes(fill = LHD_NAME), show.legend = FALSE)