Skip to contents

The geometries have been simplified with a tolerance of 500 m to reduce the level of detail.

Usage

phn

Format

An object of class sf (inherits from tbl_df, tbl, data.frame) with 10 rows and 9 columns.

National Recovery and Resilience Agency, "PHN Boundaries used by the NBRA", https://data.gov.au/data/dataset/phn-boundaries-used-by-the-nbra, accessed 9 March 2026.

The original dataset is published under the Creative Commons Attribution 2.5 Australia licence, © Commonwealth of Australia 2025.

Examples

library(ggplot2)
ggplot(phn) + geom_sf(aes(fill = PHN_NAME), show.legend = FALSE)